FitCorCbmRoc; seed = 123A binned dataset suitable for analysis by FitCorCbmRoc. It was generated by
DfCreateCorCbmDataset by setting the seed variable to 123. Note
the formatting of the data as a single treatment two reader dataset, even though
the actual pairing might be different, see FitCorCbmRoc. The dataset is
intentionally large so as to demonstrate the asymptotic convergence of ML estimates,
produced by FitCorCbmRoc, to the population values. The data was generated
by the following argument values to DfCreateCorCbmDataset: seed = 123,
K1 = 5000, K2 = 5000, desiredNumBins = 5, muX = 1.5, muY = 3, alphaX = 0.4,
alphaY = 0.7, rhoNor = 0.3, rhoAbn2 = 0.8.
datasetBinned123A list with 8 elements:
NL Ratings array [1, 1:2, 1:10000, 1], of non-lesion localizations, NLs
LL Ratings array [1, 1:2, 1:5000, 1], of lesion localizations, LLs
lesionVector array [1:5000], number of lesions per diseased case, all set to one
lesionID array [1:5000, 1], lesions labels on diseased cases, all set to one
lesionWeight array [1:5000, 1], weights, all set to one
dataType "ROC", the data type
modalityID "1", treatment label
readerID [1:2] "1" "2", reader labels
Zhai X, Chakraborty DP (2017). A bivariate contaminated binormal model for robust fitting of proper ROC curves to a pair of correlated, possibly degenerate, ROC datasets. Medical Physics. 44(6):2207--2222.
# NOT RUN {
str(datasetBinned123)
# }
Run the code above in your browser using DataLab