NL Ratings array [1, 1:2, 1:10000, 1], of non-lesion localizations, NLs
LL Ratings array [1, 1:2, 1:5000, 1], of lesion localizations, LLs
lesionVector array [1:5000], number of lesions per diseased case, all set to one
lesionID array [1:5000, 1], lesions labels on diseased cases, all set to one
lesionWeight array [1:5000, 1], weights, all set to one
dataType "ROC", the data type
modalityID "1", treatment label
readerID [1:2] "1" "2", reader labels