NL Ratings array [1, 1, 1:15, 1], of false positives, FPs
LL Ratings array [1, 1, 1:10, 1], of true positives, TPs
lesionVector array [1:10], number of lesions per diseased case, all set to 1
lesionID array [1:10, 1], labels of lesions on diseased cases, all set to 1
lesionWeight array [1:10, 1], weights (or clinical importance) of lesions, all set to 1
dataType "ROC", the data type
modalityID "1", treatment label
readerID "1", reader label